@@ -1,7 +1,7 @@
 """
 Type annotations for iot-data service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_data/type_defs/)
 
 Usage::
 
@@ -12,10 +12,9 @@ Usage::
     ```
 """
 import sys
-from typing import IO, Dict, List, Union
+from typing import IO, Any, Dict, List, Union
 
 from botocore.response import StreamingBody
-from typing_extensions import NotRequired
 
 if sys.version_info >= (3, 9):
     from typing import TypedDict
@@ -199,7 +198,7 @@ _OptionalPublishRequestRequestTypeDef = TypedDict(
     {
         "qos": int,
         "retain": bool,
-        "payload": Union[bytes, IO[bytes], StreamingBody],
+        "payload": Union[str, bytes, IO[Any], StreamingBody],
     },
     total=False,
 )
@@ -237,7 +236,7 @@ _RequiredUpdateThingShadowRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateThingShadowRequestRequestTypeDef",
     {
         "thingName": str,
-        "payload": Union[bytes, IO[bytes], StreamingBody],
+        "payload": Union[str, bytes, IO[Any], StreamingBody],
     },
 )
 _OptionalUpdateThingShadowRequestRequestTypeDef = TypedDict(
